<?php
/*
Plugin Name: Simple Input Tabs
Description: Adds additional user inputs where required in the theme.
Version: 1.8f
Author: Jason Dixon
Author URI: http://simpleextrainputs.internetimagery.com
*/

# get correct id for plugin
$thisfile=basename(__FILE__, '.php');

# register plugin
register_plugin(
	$thisfile, //Plugin id
	'Simple Input Tabs', 	//Plugin name
	'1.8f', 		//Plugin version
	'Jason Dixon',  //Plugin author
	'http://simpleextrainputs.internetimagery.com', //author website
	'Adds additional user inputs where required in the theme', //Plugin description
	'', //page type - on which admin tab to display
	''  //main function (administration)
	);
// Sort out hooks.
add_action('common','SIT_autoload_compatilitly_mode');
add_action('common','SIT_set_tabs_hook');
add_action('edit-above-content','SIT_edit_box');
add_action('edit-content','SIT_edit_foot');//					Add some new page tabs below the content edit box.
add_action('changedata-save','SIT_save_file');//				Intercept file save before it is saved.
add_action('index-pretemplate','SIT_generate_data');//			Extract content data when page is loaded.
add_filter('content','SIT_page_content_filter');//					Intercept content before it is put to page.
add_action('footer','SIT_change_edit_data');

$SIT_OPTIONS = array();
$SIT_COMPATIBILITY = array();
function SIT_options(){
global $SIT_COMPATIBILITY;




//				======SIMPLE CONFIGURATION OPTIONS======

/*	---------------------------------------------------------------------------------
*	IF YOU WISH TO TURN OFF THIS PLUGINS' ERROR 404 MESSAGES, CHANGE: true TO: false.
*	---------------------------------------------------------------------------------*/
	SIT_set_option('error404', true);
	/*-------------------------------------------------------------------------------*/


/*	---------------------------------------------------------------------------------
*	CHANGE THE NUMBER TO DISPALY TABS IN DIFFERENT LOCATIONS:
*	3	=	Javascript tabs above the edit box. No page reloads.
*	2	=	Button tabs above the edit box. Page reloads each tab change.
*	1	=	Button tabs below the edit box. Classic mode. Page reloads.
*	0	=	DEBUGGING: All tabs visible. Don't use this.
*	---------------------------------------------------------------------------------*/
	SIT_set_option('tab-location', 3);
	/*-------------------------------------------------------------------------------*/


/*	---------------------------------------------------------------------------------
*	IF YOU WANT TO GIVE PERMISSION TO HAVE PLUGINS PLACE DATA ON TOP OR BELOW YOUR
*	!!EXTRA!! CONTENT, CHANGE: false TO: true. (PLUGINS CAN STILL PLACE DATA ABOVE OR
*	BELOW YOUR 'MAIN' CONTENT SECTION REGARDLESS OF THIS SETTING.
*	---------------------------------------------------------------------------------*/
	SIT_set_option('content-top', false);
	SIT_set_option('content-bottom', false);
	/*-------------------------------------------------------------------------------*/

/*	---------------------------------------------------------------------------------
*	IF YOU WISH TO CHANGE THE COLOUR OF THE CURRENTLY ACTIVE TAB, EDIT THIS VARIABLE.
*	---------------------------------------------------------------------------------*/
	SIT_set_option('active-tab-colour', '#96f4b4');
	/*-------------------------------------------------------------------------------*/

/*	---------------------------------------------------------------------------------
*	IF YOU WANT TO FORCE SIMPLE INPUT TABS INTO COMPATIBILITY MODE, THEN CHANGE THE
*	CORRESPONDING PLUGINS VALUE TO: true.
*	e.g.	$SIT_COMPATIBILITY[i18n] = true;
*
*	BEST NOT TO ALTER THIS UNLESS YOU KNOW A PLUGIN IS THERE AND SIMPLE INPUT TABS
*	IS HAVING TROUBLE FINDING IT AUTOMATICALLY.
*	---------------------------------------------------------------------------------*/
	$SIT_COMPATIBILITY['i18n'] = false;//	--	--	--	--	--	i18n plugin.
	$SIT_COMPATIBILITY['Small Plugin Toolkit'] = false;//	--	Small Plugin Toolkit plugin.
}	/*-------------------------------------------------------------------------------*/


//				======DON'T CHANGE ANYTHING BEYOND THIS LINE======


//				======TEMPLATE FUNCTIONS======

/*	---------------------------------------------------------------------------------
*	Functions below are for use in template files by template creators.
*	The idea is to have the option to keep consistency by using a naming convention.
*	You can still use GetSimpleCMS's normal functions, and they will do what they have always done.
*	get_page_content() should be replaced with insert_page_content() however.
*	---------------------------------------------------------------------------------*/

function insert_page_content($field = NULL,$blurb=NULL){//			Output users content to page
	$field = trim($field);
	SIT_tab_content_output($field,$blurb);}//					Use -> to output a different pages content.

function insert_page_header(){//						Output header information
	get_page_header();}

function insert_page_footer(){//						Output footer information
	get_page_footer();}

function insert_page_navigation($nav=NULL){//					Output page navigation
	if(function_exists('get_i18n_navigation')){
		get_i18n_navigation($nav);}
	else {
		get_navigation($nav);}}

function return_tab_content($location){//					Return a specific tabs content for processing.
	$query = explode('->', $location);
	if (count($query)==2){
	return SIT_hunt_page_data($query[0], $query[1]);}
	else { return SIT_text('TAB_RETURN_PROBLEM');}
}	/*-------------------------------------------------------------------------------*/



//				======COMPATIBILITY FUNCTIONS======

/*	---------------------------------------------------------------------------------
*	SIMPLE INPUT TABS COMPATIBILITY. AUTOMATICALLY ENABLE IF PLUGIN EXISTS AND IS ACTIVE.
*	---------------------------------------------------------------------------------*/
function SIT_autoload_compatilitly_mode(){
global $SIT_COMPATIBILITY, $live_plugins;
if(array_key_exists('i18n_base.php',$live_plugins)&&$live_plugins['i18n_base.php']){$SIT_COMPATIBILITY['i18n'] = true;}//	i18n compatibility.
if(array_key_exists('small_plugin_toolkit.php',$live_plugins)&&$live_plugins['small_plugin_toolkit.php']){$SIT_COMPATIBILITY['Small Plugin Toolkit'] = true;}// SPT compatibility.
}	/*-------------------------------------------------------------------------------*/

/*	---------------------------------------------------------------------------------
*	COMPATIBILITY WITH I18N PLUGIN.
*	---------------------------------------------------------------------------------*/
function SIT_i18n_template_fix($url){//			Find the original template from the original file.
	global $SIT_COMPATIBILITY;
	if($SIT_COMPATIBILITY['i18n']){
		$language_list = return_i18n_available_languages();
		$split_template = explode('_', $url);
		$template_len = count($split_template);
		$check_template = $split_template[0];
		if($template_len>1){
		$template_lang = $split_template[$template_len-1];
		for($i=1;$i<=($template_len-2);$i++){//					Reassemble any underscores.
			$check_template .= '_' . $split_template[$i];}}
		if(in_array($template_lang, $language_list)){//  make sure the file is a language file.
			$file = GSDATAPAGESPATH . $check_template . '.xml';
			if (file_exists($file)) {
				$data = getXML($file);
				return $data->template;
			} else { return false; }
		} else { return false; }
	} else { return false; }
}	/*-------------------------------------------------------------------------------*/

/*	---------------------------------------------------------------------------------
*	COMPATIBILITY WITH SMALL PLUGIN TOOLKIT.
*	---------------------------------------------------------------------------------*/
function SIT_set_tabs_hook(){
	global $SIT_COMPATIBILITY;
	if($SIT_COMPATIBILITY['Small Plugin Toolkit']!=true){
	global $plugins;
	$plugins[] = array(
			'hook' => 'edit-extras',
			'function' => 'SIT_edit_box',
			'args' => array(),
			'file' => 'simple_input_tabs.php',
	    'line' => '26'
	    );}
}	/*-------------------------------------------------------------------------------*/


//				======FRONT END FUNCTIONS======

/*	----------------------------------------------------------------------------------
*	If someone calls get_page_content(), warn them to change it in the 'display tab location' view.
*	---------------------------------------------------------------------------------*/
function SIT_page_content_filter($request){
	if(isset($_GET['display'])&&$_GET['display'] == 'preview'){// 					Are we looking at a preview?
		echo strip_decode('<center><h4>'.SIT_text('SECTION_CODE').'<br>&amp;lt;?php get_page_content(); ?&amp;gt;<br>'.SIT_text('REPLACE_CODE').'<br>&amp;lt;?php insert_page_content(); ?&amp;gt;</h4></center>');}
	else if(trim($request)==NULL){
		return SIT_error404();}
	else {return $request;}
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Output the data to the page in the correct place!
*	---------------------------------------------------------------------------------*/
function SIT_tab_content_output($tab,$blurb=''){
	global $SIT_OPTIONS;
	global $SIT_RAW_CONTENT_DATA;
	$field = array_map('trim', explode('->',$tab));
	$check = $field[0]; if(!$check){$check = SIT_text('DEFAULT_TAB');}
	$tab_request = $check;
	if($tab_request[0] == '#'){$tab_request = substr($tab_request, 1);}
	if (trim($tab_request) == NULL){$tab_request = SIT_text('DEFAULT_TAB');}
	else { $tab_request = bling($tab_request); }
	if(isset($_GET['display'])&&$_GET['display'] == 'preview'){//				Are we previewing the page?
		global $url;
		$hand = 'style="cursor: help;"';
		$link_begin = '<element '.$hand.'onClick="window.opener.location.reload(true);window.opener.warnme=true;window.opener.location.href=\''.get_site_url(false).'/admin/edit.php?id=';
		if(count($field)==1){//							If we are looking at a tab only.
			if(substr($field[0],0,1) == '#'){ $blurb .= ' This tab is hidden.';}
			echo $link_begin.$url.'&tab-view='.str_replace(' ', '+', $tab_request);}
		else {//										If the tab is from another page.
			echo $link_begin;
			if(trim($field[0])==NULL){ $field[0] = $url; }
			echo trim($field[0]).'&tab-view=';
			if(trim($field[1])==NULL){ $field[1] = SIT_text('DEFAULT_TAB');}
			echo str_replace(' ', '+', bling($field[1]));}
		if(trim($tab == NULL)){$tab = SIT_text('DEFAULT_TAB');}
		echo '\';window.close();"><h1>'.$tab_request.'</h1><p>'.$blurb.'</p></element>';}
	else if(count($field) == 2){//						Specific request?
		if(trim($field[1])=='#'){$field[1] = substr($field[1], 1);}
		$field[1] = bling($field[1]);
		$print = SIT_hunt_page_data($field[0], $field[1]);
		echo strip_decode($print);}
	else if ($tab_request == SIT_text('DEFAULT_TAB')){
		get_page_content();}
	else if (array_key_exists($tab_request, $SIT_RAW_CONTENT_DATA)){
		if($SIT_OPTIONS['content-top']){exec_action('content-top');}
		$print = exec_filter('content', strip_decode($SIT_RAW_CONTENT_DATA[$tab_request]));
		echo exec_filter($tab_request.'-tab-content', $print);
		if($SIT_OPTIONS['content-bottom']){exec_action('content-bottom');}}
	else { echo SIT_error404();}
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Find and return the contents of a specified page / tab combination.
*	---------------------------------------------------------------------------------*/
function SIT_hunt_page_data($page=NULL,$tab=NULL){
	global $SIT_COMPATIBILITY;
	if (trim($tab == NULL)){$tab = SIT_text('DEFAULT_TAB');}//		Set default file.
	if (trim($page==NULL)){//							If no page specified. Use data from current page.
		global $SIT_RAW_CONTENT_DATA;
		$unpacked = $SIT_RAW_CONTENT_DATA;}
	else if($SIT_COMPATIBILITY['i18n']){//					If compatibility with i18n plugin is active.
		$file = return_i18n_page_data($page);//					Then let that plugin find the xml data for us.
		$content = strip_decode($file->content[0]);
		$unpacked = SIT_content_scan($content);}
	else {
	$file = getXML(GSDATAPAGESPATH . $page . '.xml');//			Find the page file and load it.
	$content = strip_decode($file->content[0]);//				Get the content from the file.
	$unpacked = SIT_content_scan($content);}//				Extract the data from content.
	$tab = bling($tab);
	if(array_key_exists($tab, $unpacked)){return $unpacked[$tab];}
	else if (count($unpacked)==1){return end($unpacked);}
	else { return SIT_error404();}//Send back the data.
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	If enabled, output an error 404 message.
*	---------------------------------------------------------------------------------*/
function SIT_error404(){
	global $SIT_OPTIONS;
	if($SIT_OPTIONS['error404']){
		return SIT_text('ERROR404');}
	else{
		return;}
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Generate tab data from page content.
*	---------------------------------------------------------------------------------*/
function SIT_generate_data(){
	if(!array_key_exists('SIT_RAW_CONTENT_DATA', $GLOBALS)){
		global $SIT_RAW_CONTENT_DATA;
		global $content;
		$SIT_RAW_CONTENT_DATA = SIT_content_scan($content);
		$content = $SIT_RAW_CONTENT_DATA[SIT_text('DEFAULT_TAB')];}
}	/*-------------------------------------------------------------------------------*/






//				======BACK END FUNCTIONS======

/*	---------------------------------------------------------------------------------
*	Triggers that happen on the page edit screen.
*	Saving page information to file and recording the tab last used etc.
*	---------------------------------------------------------------------------------*/
function SIT_edit_box(){//							Process data and display in the editor.
	global $SIT_RAW_CONTENT_DATA;
	global $SIT_COMPATIBILITY;
	global $SIT_LAST_TAB;//							Set a page to come back to after saving.
	global $SIT_TAB_LIST;//							Initialize our tab list.
	global $SIT_WARNING;//							Warning message.
	global $SIT_OPTIONS;//							Load our configurations.
	global $HTMLEDITOR;//
	global $data_edit;//							Grab the XML page file.
	global $TEMPLATE;//							Get theme folder.
	global $template;//							Get theme file.
	global $content;//							Get page content.
	$SIT_WARNING = 0;//							Preemptively set it to false. Warnings suck!

	if(isset($_GET['newid'])){//				New file? Get template if i18n plugin is installed.
		$remote_template = SIT_i18n_template_fix($_GET['newid']);
		if($remote_template != false){
			$template = $remote_template;}}

	$SIT_TAB_LIST = SIT_template_scan($TEMPLATE,$template,'insert_page_content');//Scan the template folder, gather content requests.
	if(isset($_GET['tab-view'])){//							Did we specify a tab?
		$SIT_LAST_TAB = $_GET['tab-view'];}
	else if(isset($data_edit->returnpage)){//					Check to see if a return page exists.
		$SIT_LAST_TAB = (string)$data_edit->returnpage;}//			If not, then set it to the default.
	else{$SIT_LAST_TAB = SIT_text('DEFAULT_TAB');}
	if(!array_key_exists($SIT_LAST_TAB,$SIT_TAB_LIST)){//			Check to see if the return tab is in the template.
		$SIT_LAST_TAB = key($SIT_TAB_LIST);}//				If not, then swap to a relevant tab.

	echo '<!--- '.SIT_text('SIT_ADDED')." ---> \n";//	Store record of the last tab viewed.
	echo '<input type="hidden" id="lastpage-view" name="lastpage-view" value="'.safe_slash_html($SIT_LAST_TAB).'">';
	//									Store raw content data for retrieval later.
	echo '<input type="hidden" id="old-page-content" name="old-page-content" value="'.safe_slash_html($content).'">';

	$SIT_RAW_CONTENT_DATA = SIT_content_scan($content);//			Extract the data from the page xml file.
	if($content == NULL){//			If the page is fresh add in welcome message.
		$content = '<p></p><h1>'.SIT_text('WELCOME_NEW_PAGE').'</h1><p>'.SIT_text('WELCOME_PAGE_BLURB').'</p>';}
		else {//					Leave the content alone. Otherwise if there is data,
	$content = $SIT_RAW_CONTENT_DATA[$SIT_LAST_TAB];}//				pick the correct tab data to display to the user.
	if(trim($content) == NULL){//						If the content is a new tab, throw in a message.
		if($SIT_TAB_LIST == NULL){$content = $SIT_RAW_CONTENT_DATA[SIT_text('DEFAULT_TAB')];}
		else if($SIT_TAB_LIST[$SIT_LAST_TAB] == NULL){
		$content = SIT_text('WELCOME_TAB_BLURB').' '.$SIT_LAST_TAB;}
		else { $content = $SIT_TAB_LIST[$SIT_LAST_TAB];}}

	if($SIT_OPTIONS['tab-location'] == 3 && $HTMLEDITOR != 1){$SIT_OPTIONS['tab-location'] = 2;}// check HTML editor.

	if($SIT_COMPATIBILITY['Small Plugin Toolkit'] != true){echo '</div><div>';}
	SIT_display_warning($SIT_WARNING);
	if(!$SIT_OPTIONS['tab-location']||$SIT_OPTIONS['tab-location'] == 3){SIT_top_tabs();} if (!$SIT_OPTIONS['tab-location']||$SIT_OPTIONS['tab-location'] == 2){SIT_bottom_tabs();}
	if($SIT_COMPATIBILITY['Small Plugin Toolkit'] != true){echo '</div><div id="default-WYSIWYG" style="clear: both;"><div>';}
}

function SIT_edit_foot(){//							Print out tabs below the text input box.
	global $SIT_COMPATIBILITY;
	global $SIT_LAST_TAB;//							Get the active tab name.
	global $SIT_TAB_LIST;//							Get the list of tab names.
	global $SIT_OPTIONS;//					Get the active tab style.
	global $HTMLEDITOR;//

	if($SIT_COMPATIBILITY['Small Plugin Toolkit'] != true){ echo '</div>'; }

	echo '<!--- '.SIT_text('SIT_ADDED')." ---> \n";
	if($SIT_OPTIONS['tab-location'] == 0 ||$SIT_OPTIONS['tab-location'] == 1){SIT_bottom_tabs();}//					Create some tabs for each input.
	if(count($SIT_TAB_LIST)>1){//						Only display this info if there is more than one tab.
	if($SIT_OPTIONS['tab-location'] != 3){ echo SIT_text('WILL_SAVE').' ';} // Only mention tabs save when not Javatabs.
	echo SIT_text('CURRENTLY_EDITING').' <strong><span id="current-tab-name" style="color:green">'.$SIT_LAST_TAB.'</span></strong>.<br/>';}
	echo SIT_text('CHANGE_TEMPLATE').'<br></p>';
	//									Add a separate button that dispalys tab locations.
	echo '<p><img src="template/images/search.png"/> <a '.SIT_display_tab().' >'.SIT_text('PREVIEW_BUTTON').'</a></p>';
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Display warning if one exists!
*	---------------------------------------------------------------------------------*/
function SIT_display_warning($warning){
	if($warning!=0){
		echo '<div class="updated">'.SIT_text('WARNING').' ';
		switch($warning){
			case 1://						There is a duplicate tab in the theme.
			echo SIT_text('DUPLICATE_TABS');
			break;

			case 2://						There are illegal tabs hidden.
			echo SIT_text('ILLEGAL_TABS');
			break;
			}
		echo '</div>';}
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Link for display tab.
*	---------------------------------------------------------------------------------*/
function SIT_display_tab(){
	global $SITEURL, $url;
	return 'href="'.$SITEURL.'index.php?id='.$url.'&display=preview" target="_blank"';
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Print out tabs on top of the edit box.
*	---------------------------------------------------------------------------------*/
function SIT_top_tabs(){
	global $SIT_LAST_TAB, $SIT_TAB_LIST;

//	echo '<input type="text" id="testboxing" value="fill" style="width:600px;" />'; // DEBUGGING. box to display things.

	$value = 'class="nav toptab" style="position:relative; margin: 0px; float:left; width:648px;';
	echo '<ul '.$value.'"><li id="pagepreview"><a class="pages" style="cursor:help;"  '.SIT_display_tab().'><img src="template/images/search.png"/></a></li>';
	$tab_width = 0;
	foreach($SIT_TAB_LIST as $newtab=>$dump){
		if($tab_width > 80){ echo '</ul><ul '.$value.' margin-top: -5px; background: #f0f0f0;">'; $tab_width = 0;}
		$tab_width += strlen($newtab) + 4;
		echo '<li class="pagetab" ><a style="font-weight: bold !important;" href="#'.$newtab.'" ';
		if($SIT_LAST_TAB == $newtab){} else { echo 'class="pages"';}
		echo '>'.$newtab.'</a></li>';}
	echo '</ul>';
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Change the editor data.
*	---------------------------------------------------------------------------------*/
function SIT_change_edit_data(){
	global $SIT_LAST_TAB, $SIT_RAW_CONTENT_DATA, $SIT_TAB_LIST, $SIT_OPTIONS, $HTMLEDITOR;
	if(!$SIT_OPTIONS['tab-location']||$SIT_OPTIONS['tab-location'] == 3 && $HTMLEDITOR == 1){?>
<script>
	currentTab = "<?php echo $SIT_LAST_TAB; ?>";
	pageData = <?php echo json_encode($SIT_RAW_CONTENT_DATA); ?>; // inital data.
	defaultTabData = <?php echo json_encode($SIT_TAB_LIST); ?>;
	defaultBlurb = "<?php echo SIT_text('WELCOME_TAB_BLURB') ?>";

//	 Swap data.
	function dataReplace(data){
		var changeEditor = CKEDITOR.instances["post-content"]; //set editor
		var getdata = changeEditor.getData();
		getdata = $("<div/>").text(getdata).html();
		var newContent = $("<div/>").html(data).text();
		if(newContent == ""){newContent = defaultBlurb + " " + currentTab;}
		changeEditor.setData(newContent, function(){
		changeEditor.document.on("keyup", function(event){ $('#editform').trigger('change');}); });
		return getdata;}

// A fix for javascripts stringify outputting characters that php doens't accept.
//		myJSONString.escapeSpecialChars();
String.prototype.escapeSpecialChars = function() {
    return this.replace(/\\n/g, "\\n")
               .replace(/\\'/g, "\\'")
               .replace(/\\"/g, '\\"')
               .replace(/\\&/g, "\\&")
               .replace(/\\r/g, "\\r")
               .replace(/\\t/g, "\\t")
               .replace(/\\b/g, "\\b")
               .replace(/\\f/g, "\\f");
};

//	Lets go!
	$(document).ready(function(){

//	draw attention to the preview tab. PRETTY!
	$("#pagepreview a").hover(function(){
			$(this).removeClass("pages");},
		function(){
			$(this).addClass("pages");
		});

//	Make the tabs... well... work.
		$(".toptab .pagetab a").click(function(event){
			event.preventDefault(); // prevent the links from working.
			var newTab = $(this).text(); // set new tab.
			$(".toptab li a").addClass("pages"); // change tab colours.
			$(this).removeClass("pages");

			if(!pageData[newTab]){
				if(defaultTabData[newTab]){ pageData[newTab] = defaultTabData[newTab];}
				else { pageData[newTab] = defaultBlurb + " " + newTab;} // if no content, set default.
				}
			pageData[currentTab] = dataReplace(pageData[newTab]); // put in new data.
			currentTab = newTab;

			$("#current-tab-name").text(currentTab);//		Change the tab display text.
			$("#lastpage-view").val(currentTab); // Save last tab to restore later.
			var infoString = JSON.stringify(pageData);
			var saveInfo = infoString.escapeSpecialChars();
			$("#old-page-content").val(saveInfo); // save data to form.
		});
	});
</script><?php
}}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Print out tabs underneath the edit box.
*	---------------------------------------------------------------------------------*/
function SIT_bottom_tabs(){
	global $SIT_TAB_LIST, $SIT_LAST_TAB, $SIT_OPTIONS;
	echo '<p>';
	foreach($SIT_TAB_LIST as $tab_name=>$value){
	$active_tab = '';
	$shadow_details = 'inset 0px 2px 3px 0px #acacac';//			Make a fancy shadow for the selected tab.
	if($tab_name == $SIT_LAST_TAB){//					Make a special style for the active tab,
		$active_tab = $SIT_OPTIONS['active-tab-colour'];//			and make the tab un-clickable.
		echo '<span><input class="submit" style="background:'.$active_tab.'; -webkit-box-shadow: '.$shadow_details.'; -moz-box-shadow:'.$shadow_details.'; box-shadow: '.$shadow_details.';" type="button" name="submitted" value="'.$tab_name.'" onclick="warnme=false;" /></span>';
	} else {
	echo '<span><input class="submit" type="submit" name="submitted" value="'.$tab_name.'" onclick="warnme=false;" /></span>';}
	}
	echo '</p>';
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Get a list of all pages. -- depreciated but might be useful in the future
*	---------------------------------------------------------------------------------*/
function SIT_list_pages(){
	$large_list = get_available_pages();
	for($i=0;$i<=(count($large_list)-1);$i++){
		$shortlist[$i] = bling($large_list[$i]['slug']);}
		return $shortlist;
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Parse the template file. Return values from within insert_page_content( ... );
*	Return with default tab if there are no calls to this plugin on the template.
*	---------------------------------------------------------------------------------*/
function SIT_template_scan($theme_folder,$theme_file,$function){
	global $SIT_WARNING, $SIT_OPTIONS, $url;//							Establish warnings.
	$validated_list = array();//						Establish empty array.
	$template_url = GSTHEMESPATH . $theme_folder . '/' . $theme_file;//	Find the template file.
	$the_file = file_get_contents($template_url);//				And scan the file.
	preg_match_all("/<\?php.*?\b".$function."\(([^)]*?)\);?.*?\?>/si", $the_file, $result_list);
	$search = array('"',"'"); //						Things we want to remove. Brackets.
	foreach($result_list[1] as $value){//			Go through and make a new list.
		$value = explode(',', str_replace($search, '', $value),2);
		$tab_value = explode('->', $value[0]);
		$tab = bling($tab_value[0]);//					Pull out the tab name.
		if($tab == NULL){$tab = SIT_text('DEFAULT_TAB');}//
		if(count($tab_value)>1){//				Is the tab a specific request?
			$page = trim($tab_value[0]);
			$special_tab = bling($tab_value[1]);
			if($special_tab == NULL){$special_tab = SIT_text('DEFAULT_TAB');}
			if($page == NULL || $page == $url){//		Are we looking at the specified page?
				if(preg_match('/^[\w_-\s]+$/',$tab)){
					if(!array_key_exists($special_tab, $validated_list)){
						$validated_list[$special_tab] = $value[1];}}}}// Create a tab on the page.
		else if(!preg_match('/^[\w_-\s]+$/',$tab)){//		Check the tab if it has illegal characters.
			if($tab[0] != '#'){
		$SIT_WARNING = 2;}}//						Warn that the tab is illegal and dump it.
		else if(array_key_exists($tab, $validated_list)){//		Check for duplicates.
			$SIT_WARNING = 1;}//					Trigger duplicate warning.
		else { if(!isset($value[1])){$value[1] = NULL;}
		 $validated_list[$tab] = $value[1];}//			Add tab to the list.
	}
	if($SIT_OPTIONS['error404'] == false){ $SIT_WARNING = 0; }
	return $validated_list;
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Parse the content data. Return values from ||] ... [||
*	---------------------------------------------------------------------------------*/
function SIT_content_scan($string){
$json_attempt = json_decode($string,true); // try json first.
if($json_attempt){ return $json_attempt; }
$string_array = explode('||', $string);//					Break up our string.
$content = NULL;//								Set an empty data variable. Lets fill it!
$previous_tab = NULL;//								Set tab memory.
$array_location = 'Beginning';//						Set string location.
foreach($string_array as $item){//						Begin extracting the content data.
	if (substr($item,0,1) == ']' && substr($item,-1) == '['){ //		Is the current item a tab?
		$item = str_replace(']', '', $item);
		$item = str_replace('[', '', $item);//				Take out the ] [ characters.
		$content[$item] = '';
		$previous_tab = $item;//					Save this tab in the memory, for next string.
		$array_location = 'Tab';}//					Where are we in the data? We are working with tabs.
	else {//								Guess the item is not a tab...
		if ($array_location == 'Tab'){//				Last item was a tab. This must then be the data.
			$content[$previous_tab]=$item;//			Add content to the key of the previous tab.
			$array_location = 'Data';}//				We are now in the data.
		else if($array_location == 'Data'){//				We are still in data. We accidentally grabbed ||.
			$content[$previous_tab].= '||'.$item;}//			Put them back in. Clean up our messes.
		else if($array_location == 'Beginning'){//			If we are at the beginning, make it the default tab.
			$content[SIT_text('DEFAULT_TAB')] = $item;
			$previous_tab = SIT_text('DEFAULT_TAB');
			$array_location = 'Data';}
		}}
	return $content;//						Return the data!
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Make text look pretty. Gotta look presentable!
*	---------------------------------------------------------------------------------*/
function bling($text){
	return trim(ucwords(strtolower($text)));
}	/*-------------------------------------------------------------------------------*/


/*	----------------------------------------------------------------------------------
*	Intercepting the saving of the page file.
*	Extracting the users input data, and adding our own tags to it.
*	Sending back the result!
*	---------------------------------------------------------------------------------*/
function SIT_save_file(){
	global $xml, $url;//								Hijack the page save file.

	$i18n_template = SIT_i18n_template_fix($url);//	Get original file if i18n plugin is buggering with them.
	if($i18n_template != false){
		$xml->template[0] = '';
		$xml->template[0]->addCData($i18n_template);}

	if(isset($_POST['submitted'])){//					Probably pointless to check, but best to be safe.
		if($_POST['lastpage-view'] != NULL){
		$last_tab = $_POST['lastpage-view'];}//				Get the last tab that was open.
		else{$last_tab = SIT_text('DEFAULT_TAB');}
		if($_POST['submitted'] == i18n_r('BTN_SAVEUPDATES') || $_POST['submitted'] == i18n_r('BTN_SAVEPAGE')){
			$return_tab = $last_tab;//				Check to see if the page has just been saved
		} else {//							or if the tab has been changed.
			$return_tab = $_POST['submitted'];}//			Get the last tab viewed, so we can return there.
		$last = $xml->addChild('returnpage');//				Insert record of last tab viewed.
		$last->addCData($return_tab);

		$new_information = (string)$xml->content[0];//			Pull out the newly entered information.
		$old_information = SIT_content_scan($_POST['old-page-content']);//Original page information.
		$old_information[$last_tab] = $new_information;//		insert the new information replacing the old.
		$save_info = $old_information[SIT_text('DEFAULT_TAB')];//   place the default tab at the start of the file.
		unset($old_information[SIT_text('DEFAULT_TAB')]);// remove default tab from list.
		foreach($old_information as $k=>$v){//				Compile data back into single string.
			$each_tab = safe_slash_html('||]'.$k.'[||');//		Ensure the tab name is secure with safe_slash_html.
			$save_info .= $each_tab.$v;}//				Put em together.
		$xml->content[0] = '';//					Clear the XML data.
		$xml->content[0]->addCData($save_info);}//			Insert our altered information.
}	/*-------------------------------------------------------------------------------*/

/*	----------------------------------------------------------------------------------
*	If option isn't specified externally. Set it internally.
*	---------------------------------------------------------------------------------*/
function SIT_set_option($option, $value){
	global $SIT_OPTIONS;
	if(!array_key_exists($option, $SIT_OPTIONS)){
		$SIT_OPTIONS[$option] = $value;}
}	/*-------------------------------------------------------------------------------*/


//				======LANGUAGE FUNCTIONS======

/*	---------------------------------------------------------------------------------
*	Check if there is an external language file, and if so use it.
*	Otherwise use one of the built in languages.
*	---------------------------------------------------------------------------------*/
if(file_exists(GSPLUGINPATH . 'simple_input_tabs/lang/'.$LANG.'.php')){
	$SIT_LANG_EXTERNAL = true;//						Check if there is an external language file,
	i18n_merge('simple_input_tabs');}//					if not then use a local language.
else{
	$SIT_LANG_EXTERNAL = false;
	SIT_internal_language();}

SIT_options();//						Get configuration options. Priority goes to external options.

function SIT_text($words){//							Translate the request into the language.
	global $SIT_LANG_EXTERNAL;//						Get language location.
	if($SIT_LANG_EXTERNAL){//					Do we have an external language file?
		return i18n_r('simple_input_tabs/'.$words);}
		else{//								Guess it must be a local language.
		global $SIT_I18N_LOCAL;
		return $SIT_I18N_LOCAL[$words];}
}	/*-------------------------------------------------------------------------------*/

/*	----------------------------------------------------------------------------------
*	Built in Language text. Can be translated directly in here if desired.
*	Simply copy/paste the code between "case" and "break" and add in your own translations.
*	---------------------------------------------------------------------------------*/
function SIT_internal_language(){
global $SIT_I18N_LOCAL, $LANG;
switch ($LANG)
{
// TRANSLATE ME!!
case '': // insert language "name" ie: en_US for english.
$SIT_I18N_LOCAL = array(
// Nice little message in the source code
'SIT_ADDED' => '',
//name of default tab!
'DEFAULT_TAB' => '',
// Welcome messages that appear when new pages and/or tabs are opened.
'WELCOME_NEW_PAGE' => '',
'WELCOME_PAGE_BLURB' => '',
'WELCOME_TAB_BLURB' => '',
//error messages
'ERROR404' => '',
'TAB_RETURN_PROBLEM' => '',
'DUPLICATE_TABS' => '',
'ILLEGAL_TABS' => '',
'WARNING' => '',
//helpful messages
'WILL_SAVE'			=> '',
'CURRENTLY_EDITING' => '',
'CHANGE_TEMPLATE' => '',
'TAB_SECTION_NAME' => '',
'PREVIEW_BUTTON' => '',
// preview page
'SECTION_CODE' => '',
'REPLACE_CODE' => ''
);
break;

// Spanish
// Translated by islander. Thank you.

case 'es_ES': // insert language "name" ie: en_US for english.
$SIT_I18N_LOCAL = array(
// Nice little message in the source code
'SIT_ADDED' => 'Agregado por el plugin de Simple Input Tabs',
//name of default tab!
'DEFAULT_TAB' => 'Principal',
// Welcome messages that appear when new pages and/or tabs are opened.
'WELCOME_NEW_PAGE' => '&iexcl;Bienvenidos a la nueva p&aacute;gina!',
'WELCOME_PAGE_BLURB' => 'Quitar este texto y a&ntilde;adir su contenido aqu&iacute;. Abajo hay unas pesta&ntilde;as nombradas. &Uacute;salos para agregar contenido a las diferentes &aacute;reas de su p&aacute;gina web. No se olvide de a&ntilde;adir un t&iacute;tulo a su p&aacute;gina, arriba.',
'WELCOME_TAB_BLURB' => 'A&ntilde;adir el contenido de la secci&oacute;n:',
//error messages
'ERROR404' => 'Error 404: El contenido solicitado no fue encontrado.',
'TAB_RETURN_PROBLEM' => 'Hubo un problema con su pedido de pesta&ntilde;a.',
'DUPLICATE_TABS' => 'Su plantilla seleccionada tiene pesta&ntilde;as duplicadas del mismo nombre.',
'ILLEGAL_TABS' => 'Hay una o m&aacute;s fichas de su plantilla que utilizan caracteres no v&aacute;lidos. Ellos han estado oculta.',
'WARNING' => '&iexcl;ADVERTENCIA!',
//helpful messages
'WILL_SAVE'			=> 'Al hacer clic en una pesta&ntilde;a de arriba guardar y cambiar las entradas.',
'CURRENTLY_EDITING' => 'Est&aacute; editando el archivo:',
'CHANGE_TEMPLATE' => 'Si cambia la plantilla de p&aacute;gina, necesitar&aacute; que guardar para actualizar sus fichas.',
'TAB_SECTION_NAME' => 'El contenido de esta pesta&ntilde;a va en:',
'PREVIEW_BUTTON' => 'Mostrar ubicaciones de pesta&ntilde;as.',
// preview page
'SECTION_CODE' => 'Esta secci&oacute;n est&aacute; poblado por el c&oacute;digo:',
'REPLACE_CODE' => 'Para funcionar bien, debe cambiar el c&oacute;digo a:'
);
break;

// ENGLISH
default:
$SIT_I18N_LOCAL = array(
// Nice little message in the source code
'SIT_ADDED' => 'Added by the Simple Input Tabs Plugin',
//name of default tab!
'DEFAULT_TAB' => 'Main',
// Welcome messages that appear when new pages and/or tabs are opened.
'WELCOME_NEW_PAGE' => 'Welcome to your new page!',
'WELCOME_PAGE_BLURB' => 'Remove this text and add your content here. Use named tabs to add content to different areas of your web page. Don\'t forget to add a title to your page, above.',
'WELCOME_TAB_BLURB' => 'Add your content to the section:',
//error messages
'ERROR404' => 'Error 404: Content requested was not found.',
'TAB_RETURN_PROBLEM' => 'There was a problem with your Tab request.',
'DUPLICATE_TABS' => 'Your selected Template has duplicate Tabs of the same name.',
'ILLEGAL_TABS' => 'There are one or more Tabs in your template that use illegal characters. They have been hidden.',
'WARNING' => 'WARNING!',
//helpful messages
'WILL_SAVE'				=> 'Clicking a Tab above will SAVE and switch inputs.',
'CURRENTLY_EDITING'		=> 'You are currently editing:',
'CHANGE_TEMPLATE' => 'If you change the Page Template, you will need to SAVE in order for your Tabs to update.',
'TAB_SECTION_NAME' => 'Content for this Tab goes in:',
'PREVIEW_BUTTON' => 'Display Tab Locations.',
// preview page
'SECTION_CODE' => 'This section is populated by the code:',
'REPLACE_CODE' => 'For proper functionality you should change the code to:'
);
break;
}
//$SIT_I18N_LOCAL['DEFAULT_TAB'] = bling($SIT_I18N_LOCAL['DEFAULT_TAB']);//	MAke sure the default tab is fancy.
}	/*-------------------------------------------------------------------------------*/?>